@@ -168,43 +168,25 @@ def batch_import(self, batch_id):
 def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
     load = ImportQueue.objects.get(pk=importqueue_pk)
     
-    """
-    # TODO: Sim. to the batch_import blocks that are commented out above, these bits are more important for an integration step. They exist to prevent double-loading into a common table, but I don't necessarily want to prevent making duplicate staging tables for a given File object.
-    
-    destination = load.batch.destination
-    similar_load_qs = ImportQueue.objects.filter(
-        batch__destination=destination,
-        file__state=load.file.state,
-        file__year=load.file.year,
-        file__file_type__source=load.file.file_type.source
-        )
-    similar_completed = similar_load_qs.filter(complete__isnull=False, status='SUCCESS')
-    similar_started = similar_load_qs.filter(start__isnull=False)
-    
-
-    if similar_completed.count() > 0:
-        #appears to already have been imported. skip this one
-        logger.warning('It looks like <%s> was already imported successfully to <%s> at %s; skipping for now' % (load, destination, similar_completed[0].complete))
-        load.fail()
-        return False
-    
-    elif similar_started.count() > 0:
-        #appears to already have been imported. skip this one
-        logger.warning('It looks like an import was already started for importing <%s> to <%s> at %s; skipping for now' % (load, destination, similar_started[0].start))
-        load.fail()
-        return False
-
-    else:
-    """
     # proceed with making the file happen
     load.status = 'QUEUED'
     load.save()
     
-    logger.info('Queued for dispatch: %s' % (load))
+    logger.info('Queued for import dispatch: %s' % (load))
     
-    dsabbr = load.file.file_type.source.abbreviation
+    try:
+        pg_import_file(load.pk)
+        return True
+    except:
+        logger.info("Encountered an error while importing %s. Check logs for details." % load)
+        load.fail(sys.exc_info()[0])
+        return False
     
     # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
+    # These parts are deprecated. postgresql and psycopg2 are now requirements.
+    """    
+    dsabbr = load.file.file_type.source.abbreviation
+    
     if ('psycopg2' in DB_BACKEND and (
             ((dsabbr.upper() in [
                     'CORE',
@@ -220,14 +202,20 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
             )
         ):
         # do it Rockapella
-        logger.info('Sending to pg_import_file: %s' % (load))
-        pg_import_file.delay(load.pk)
-        return True
+        logger.info('Loading with pg_import_file: %s' % (load))
+        try:
+            pg_import_file(load.pk)
+            return True
+        except:
+            logger.info("Encountered an error while importing %s. Check logs for details." % load)
+            load.fail(sys.exc_info()[0])
+            return False
     
     else:
-        logger.info('Sending to chunk_import_file: %s' % (load))
+        logger.info('Loading with chunk_import_file: %s' % (load))
         chunk_import_file.delay(load.pk)
         return True
+    """
 
 
 @celery.shared_task(bind=True, ignore_result=True)
@@ -510,6 +498,25 @@ def batch_complete(self, batch_pk):
         raise self.retry(exc=Exception('Batch not yet complete: %s' % b))
 
 
+@celery.shared_task(bind=True, ignore_result=True)
+def stage_dispatch(self, stagingqueue_pk):
+    stg_q = StagingQueue.objects.get(pk=stagingqueue_pk)
+    
+    # proceed with making the file happen
+    stg_q.status = 'QUEUED'
+    stg_q.save()
+    
+    logger.info('Queued for staging: %s' % (stg_q))
+    
+    try:
+        pg_stage(stg_q.pk)
+        return True
+    except:
+        logger.info("Encountered an error while staging %s. Check logs for details." % stg_q)
+        stg_q.fail(sys.exc_info()[0])
+        return False
+
+
 @celery.shared_task(bind=True, ignore_result=True)
 def pg_stage(self, stagingqueue_pk):
     """Processes StagingQueue object with primary key stagingqueue_pk. Automatically creates and records destination table as appropriate.
@@ -698,13 +705,13 @@ def pg_stage(self, stagingqueue_pk):
             
             # get a list of UtilizationFlagger objects from PyHCUP
             # these are built using HCUP's uflag definitions
-            flaggers = pyhcup.default_uflaggers()
+            flaggers = pyhcup.default_uflaggers(state=state, year=year)
             affected_rows = 0
             
             for uf in flaggers:
                 # take advantage of in-database processing for these
                 stg_q.log('%s: processing' % uf.name)
-                uflag_sql = uf.sql(output_tbl, input_tbl, pr_tbl, charges_tbl, state=state, year=year)
+                uflag_sql = uf.sql(output_tbl, input_tbl, pr_tbl, charges_tbl)
                 cursor.execute(uflag_sql)
                 uflag_count = cursor.rowcount
                 affected_rows += uflag_count
@@ -890,6 +897,8 @@ def pg_stage(self, stagingqueue_pk):
             cnxn.commit()
             
             shoveled_message = 'Generated CORE_PROCESSED table %s (%s rows)' % (output_tbl, affected_rows)
+            staged.description = 'SQL used to create table\n\n#####\n\n' + full_sql
+            staged.save()
             
         stg_q.log(shoveled_message, level='INFO', logger=logger)
 
@@ -952,7 +961,7 @@ def batch_stage(self, batch_id):
         logger.info('Begin batch %s' % (batch))
         
         job = celery.group(
-            pg_stage.si(stg.pk) for stg in enqueued
+            stage_dispatch.si(stg.pk) for stg in enqueued
             )
         job()
         
