@@ -335,7 +335,8 @@ def create_batch_from_unimported(request):
     message = 'Created ImportBatch {pk} with {length} files' \
         .format(pk=b.pk, length=len(b.importqueue_set.all()))
     
-    return importbatch_inventory(request, msg_pass_through=[message])
+    return obj_detail(request, obj_id=b.pk, obj_type="StagingBatch", msg_pt=[message])
+    #return importbatch_inventory(request, msg_pass_through=[message])
 
 
 @login_required(login_url='/login/')
